@@ -1,21 +1,10 @@
-/*****************************************************************************
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright (c) 2009 Niko Sams <niko.sams@gmail.com>                        *
- * Copyright (c) 2010 Milian Wolff <mail@milianw.de>                         *
- *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
- * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
- * (at your option) any later version.                                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2009 Niko Sams <niko.sams@gmail.com>
+    SPDX-FileCopyrightText: 2010 Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "phplanguagesupport.h"
 
@@ -87,7 +76,15 @@ LanguageSupport::~LanguageSupport()
 
 KDevelop::ParseJob *LanguageSupport::createParseJob(const IndexedString &url)
 {
-    return new ParseJob(url, this);
+    auto *job = new ParseJob(url, this);
+
+    // bypass the 5 MB maximum file size limit for the internal file
+    if (url == internalFunctionFile()) {
+        job->setMaximumFileSize(std::numeric_limits<qint64>::max());
+        job->setMinimumFeatures(TopDUContext::AllDeclarationsAndContexts);
+    }
+
+    return job;
 }
 
 QString LanguageSupport::name() const
@@ -187,3 +184,5 @@ Range LanguageSupport::specialLanguageObjectRange(const QUrl& url, const Cursor&
 }
 
 #include "phplanguagesupport.moc"
+
+#include "moc_phplanguagesupport.cpp"
